@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -20,36 +20,61 @@
  */
 
 #ifndef STOPWATCH_H
-#define	STOPWATCH_H
+#define STOPWATCH_H
 #include <iostream>
 #include "mytime.h"
 
-class StopWatch {
+#ifdef BENCHMARK
+    #define BENCHFUN StopWatch StopFun(__func__);
+    #define BENCHFUNMICRO StopWatch StopFun(__func__, true);
+#else
+    #define BENCHFUN
+    #define BENCHFUNMICRO
+#endif
+
+class StopWatch
+{
 public:
-    StopWatch( ) { stopped = false; }
-    StopWatch( const char* msg) { message = msg; start(); stopped = false; }
-    ~StopWatch() { if(!stopped) stop(); }
+
+    explicit StopWatch( const char* msg, bool microseconds = false ) : microseconds(microseconds)
+    {
+        message = msg;
+        start();
+        stopped = false;
+    }
+    ~StopWatch()
+    {
+        if(!stopped) {
+            stop();
+        }
+    }
     void start()
     {
-    	startTime.set();
+        startTime.set();
     };
     void stop()
     {
-    	stopTime.set();
-    	long elapsedTime = stopTime.etime(startTime) / 1000;
-        std::cout << message << " took " << elapsedTime << " ms" <<std::endl;
+        stopTime.set();
+        if(!microseconds) {
+            long elapsedTime = stopTime.etime(startTime) / 1000;
+            std::cout << message << " took " << elapsedTime << " ms" << std::endl;
+        } else {
+            long elapsedTime = stopTime.etime(startTime);
+            std::cout << message << " took " << elapsedTime << " us" << std::endl;
+        }
         stopped = true;
     }
     void stop(const char *msg)
     {
-    	message = msg;
-    	stop();
+        message = msg;
+        stop();
     };
 private:
-	MyTime startTime;
-	MyTime stopTime;
+    bool microseconds;
+    MyTime startTime;
+    MyTime stopTime;
     const char *message;
     bool stopped;
 };
 
-#endif	/* STOPWATCH_H */
+#endif  /* STOPWATCH_H */
