@@ -27,9 +27,6 @@ CameraConst::CameraConst()
     white_max = 0;
 }
 
-CameraConst::~CameraConst()
-{
-}
 
 bool
 CameraConst::parseApertureScaling(CameraConst *cc, void *ji_)
@@ -183,11 +180,10 @@ CameraConst::parseLevels(CameraConst *cc, int bw, void *ji_)
 CameraConst *
 CameraConst::parseEntry(void *cJSON_, const char *make_model)
 {
-    CameraConst *cc = nullptr;
     cJSON *js, *ji, *jranges;
     js = (cJSON *)cJSON_;
 
-    cc = new CameraConst;
+    CameraConst *cc = new CameraConst;
     cc->make_model = Glib::ustring(make_model);
 
     ji = cJSON_GetObjectItem(js, "dcraw_matrix");
@@ -317,6 +313,7 @@ CameraConst::parseEntry(void *cJSON_, const char *make_model)
     return cc;
 
 parse_error:
+    delete cc;
     return nullptr;
 }
 
@@ -709,6 +706,14 @@ CameraConstantsStore::CameraConstantsStore()
 {
 }
 
+
+CameraConstantsStore::~CameraConstantsStore()
+{
+    for (auto &p : mCameraConstants) {
+        delete p.second;
+    }
+}
+
 void CameraConstantsStore::init(Glib::ustring baseDir, Glib::ustring userSettingsDir)
 {
     parse_camera_constants_file(Glib::build_filename(baseDir, "camconst.json"));
