@@ -46,7 +46,7 @@ void RawImageSource::CLASS cfa_linedn(float noise)
 
     const float clip_pt = 0.8 * initialGain * 65535.0;
 
-    float eps = 1e-5;       //tolerance to avoid dividing by zero
+    const float eps = 1e-5;       //tolerance to avoid dividing by zero
 
     const float gauss[5] = {0.20416368871516755, 0.18017382291138087, 0.1238315368057753, 0.0662822452863612, 0.02763055063889883};
     const float rolloff[8] = {0, 0.135335, 0.249352, 0.411112, 0.606531, 0.800737, 0.945959, 1}; //gaussian with sigma=3
@@ -231,7 +231,7 @@ void RawImageSource::CLASS cfa_linedn(float noise)
 
                     for (int col = 16 + left, indx = rr * TS + 16; indx < rr * TS + numcols - 16; indx++, col++) {
                         if (rawData[row][col] < clip_pt && cfadn[indx] < clip_pt) {
-                            RawDataTmp[row * width + col] = CLIP((int)(cfadn[indx] + 0.5f));
+                            RawDataTmp[row * width + col] = CLIP(cfadn[indx]);
                         }
                     }
                 }
