@@ -28,7 +28,7 @@ class Coord2D
 public:
     double x, y;
     Coord2D (double x_, double y_) : x(x_), y(y_) {}
-    Coord2D () {}
+    Coord2D () : x(0), y(0) {}
     void set (double x_, double y_)
     {
         x = x_;
