@@ -5,7 +5,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -20,29 +20,24 @@
 
 #include "cplx_wavelet_dec.h"
 
-namespace rtengine {
-	
-	cplx_wavelet_decomposition::~cplx_wavelet_decomposition()
-	{
-		for(int i = 0; i <= lvltot; i++) {
-			for (int j=0; j<4; j++) {
-				delete dual_tree[i][j];
-			}
-		}
-		delete[] first_lev_anal;
-		delete[] first_lev_synth;
-		delete[] wavfilt_anal;
-		delete[] wavfilt_synth;
-	}
-	
-	wavelet_decomposition::~wavelet_decomposition()
-	{
-		for(int i = 0; i <= lvltot; i++) {
-			delete wavelet_decomp[i];
-		}
-		delete[] wavfilt_anal;
-		delete[] wavfilt_synth;
-	}
+namespace rtengine
+{
+
+wavelet_decomposition::~wavelet_decomposition()
+{
+    for(int i = 0; i <= lvltot; i++) {
+        if(wavelet_decomp[i] != nullptr) {
+            delete wavelet_decomp[i];
+        }
+    }
+
+    delete[] wavfilt_anal;
+    delete[] wavfilt_synth;
+
+    if(coeff0) {
+        delete [] coeff0;
+    }
+}
 
 };
 
