@@ -217,7 +217,6 @@ void RawImageSource::boxblur_resamp(float **src, float **dst, float ** temp, int
     #pragma omp parallel
 #endif
     {
-        float tempval;
 #ifdef _OPENMP
         #pragma omp for
 #endif
@@ -227,7 +226,7 @@ void RawImageSource::boxblur_resamp(float **src, float **dst, float ** temp, int
         for (int row = 0; row < H; row++)
         {
             int len = box + 1;
-            tempval = src[row][0] / len;
+            float tempval = src[row][0] / len;
 
             for (int j = 1; j <= box; j++) {
                 tempval += src[row][j] / len;
@@ -339,12 +338,11 @@ void RawImageSource::boxblur_resamp(float **src, float **dst, float ** temp, int
         // process remaining columns
         #pragma omp single
         {
-            float tempval;
 
             //vertical blur
             for (int col = (W / samp) - ((W / samp) % numCols); col < W / samp; col++) {
                 int len = box + 1;
-                tempval = temp[0][col] / len;
+                float tempval = temp[0][col] / len;
 
                 for (int i = 1; i <= box; i++) {
                     tempval += temp[i][col] / len;
@@ -398,23 +396,20 @@ void RawImageSource :: HLRecovery_inpaint (float** red, float** green, float** b
     int height = H;
     int width = W;
 
-    static const int range = 2;
-    static const int pitch = 4;
+    constexpr int range = 2;
+    constexpr int pitch = 4;
 
-    static const int numdirs = 4;
-
-    static const float threshpct = 0.25f;
-    static const float fixthreshpct = 0.7f;
-    static const float maxpct = 0.95f;
-    static const float epsilon = 0.00001f;
+    constexpr float threshpct = 0.25f;
+    constexpr float maxpct = 0.95f;
+    constexpr float epsilon = 0.00001f;
     //%%%%%%%%%%%%%%%%%%%%
     //for blend algorithm:
-    static const float blendthresh = 1.0;
-    static const int ColorCount = 3;
+    constexpr float blendthresh = 1.0;
+    constexpr int ColorCount = 3;
     // Transform matrixes rgb>lab and back
-    static const float trans[ColorCount][ColorCount] =
+    constexpr float trans[ColorCount][ColorCount] =
     { { 1.f, 1.f, 1.f }, { 1.7320508f, -1.7320508f, 0.f }, { -1.f, -1.f, 2.f } };
-    static const float itrans[ColorCount][ColorCount] =
+    constexpr float itrans[ColorCount][ColorCount] =
     { { 1.f, 0.8660254f, -0.5f }, { 1.f, -0.8660254f, -0.5f }, { 1.f, 0.f, 1.f } };
 
     if(settings->verbose)
