@@ -30,6 +30,7 @@
 #include "rtthumbnail.h"
 #include "profilestore.h"
 #include "../rtgui/threadutils.h"
+#include "rtlensfun.h"
 
 namespace rtengine
 {
@@ -50,6 +51,11 @@ int init (const Settings* s, Glib::ustring baseDir, Glib::ustring userSettingsDi
     Color::init ();
     PerceptualToneCurve::init ();
     RawImageSource::init ();
+    if (s->lensfunDbDirectory.empty() || Glib::path_is_absolute(s->lensfunDbDirectory)) {
+        LFDatabase::init(s->lensfunDbDirectory);
+    } else {
+        LFDatabase::init(Glib::build_filename(baseDir, s->lensfunDbDirectory));
+    }
     delete lcmsMutex;
     lcmsMutex = new MyMutex;
     dfm.init( s->darkFramesPath );
