@@ -32,8 +32,8 @@ const IptcPair strTags[] = {
     {IPTC_TAG_HEADLINE, 256, "Headline"},
     {IPTC_TAG_SPECIAL_INSTRUCTIONS, 256, "Instructions"},
     {IPTC_TAG_CATEGORY, 3, "Category"},
-    {IPTC_TAG_BYLINE, 32, "Author"},
-    {IPTC_TAG_BYLINE_TITLE, 32, "AuthorsPosition"},
+    {IPTC_TAG_BYLINE, 32, "Creator"},
+    {IPTC_TAG_BYLINE_TITLE, 32, "CreatorJobTitle"},
     {IPTC_TAG_CREDIT, 32, "Credit"},
     {IPTC_TAG_SOURCE, 32, "Source"},
     {IPTC_TAG_COPYRIGHT_NOTICE, 128, "Copyright"},
