@@ -78,8 +78,7 @@ void ImProcFunctions::vibrance (LabImage* lab)
 
 //  int skip=1; //scale==1 ? 1 : 16;
     bool skinCurveIsSet = false;
-    DiagonalCurve* dcurve = nullptr;
-    dcurve = new DiagonalCurve (params->vibrance.skintonescurve, CURVES_MIN_POLY_POINTS);
+    DiagonalCurve* dcurve = new DiagonalCurve (params->vibrance.skintonescurve, CURVES_MIN_POLY_POINTS);
 
     if (dcurve) {
         if (!dcurve->isIdentity()) {
