@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -19,13 +19,14 @@
 #ifndef _RAWMETADATALOCATION_
 #define _RAWMETADATALOCATION_
 
-namespace rtengine {
+namespace rtengine
+{
 
-    struct RawMetaDataLocation {
-        int exifBase;
-        int ciffBase;
-        int ciffLength;
-    };
+struct RawMetaDataLocation {
+    int exifBase;
+    int ciffBase;
+    int ciffLength;
+};
 }
 
 #endif
