@@ -32,27 +32,27 @@ protected:
     ColorTemp wb;
     ProgressListener* plistener;
     bool full;
-    float** hrmap[3];
-    char** needhr;
     int max[3];
     bool rgbSourceModified;
 
     //void transformPixel             (int x, int y, int tran, int& tx, int& ty);
-    void getSampleFormat (Glib::ustring &fname, IIOSampleFormat &sFormat, IIOSampleArrangement &sArrangement);
+    void getSampleFormat (const Glib::ustring &fname, IIOSampleFormat &sFormat, IIOSampleArrangement &sArrangement);
 
 public:
     StdImageSource ();
     ~StdImageSource ();
 
-    int         load        (Glib::ustring fname, bool batch = false);
-    void        getImage    (ColorTemp ctemp, int tran, Imagefloat* image, PreviewProps pp, ToneCurveParams hrp, ColorManagementParams cmp, RAWParams raw);
-    ColorTemp   getWB       ()
+    int         load        (const Glib::ustring &fname, int imageNum = 0, bool batch = false);
+    void        getImage    (const ColorTemp &ctemp, int tran, Imagefloat* image, const PreviewProps &pp, const ToneCurveParams &hrp, const ColorManagementParams &cmp, const RAWParams &raw);
+    ColorTemp   getWB       () const
     {
         return wb;
     }
     void        getAutoWBMultipliers (double &rm, double &gm, double &bm);
     ColorTemp   getSpotWB   (std::vector<Coord2D> &red, std::vector<Coord2D> &green, std::vector<Coord2D> &blue, int tran, double equal);
 
+    eSensorType getSensorType() const {return ST_NONE;}
+
     bool        isWBProviderReady ()
     {
         return true;
@@ -60,13 +60,13 @@ public:
 
     void        getAutoExpHistogram (LUTu &histogram, int& histcompr);
 
-    double      getDefGain  ()
+    double      getDefGain  () const
     {
         return 0.0;
     }
 
     void        getFullSize (int& w, int& h, int tr = TR_NONE);
-    void        getSize     (int tran, PreviewProps pp, int& w, int& h);
+    void        getSize     (const PreviewProps &pp, int& w, int& h);
 
     ImageData*  getImageData ()
     {
@@ -78,7 +78,7 @@ public:
     }
     ImageMatrices* getImageMatrices ()
     {
-        return (ImageMatrices*)NULL;
+        return (ImageMatrices*)nullptr;
     }
     bool        isRAW() const
     {
@@ -90,23 +90,20 @@ public:
         plistener = pl;
     }
 
-    void        convertColorSpace(Imagefloat* image, ColorManagementParams cmp, ColorTemp &wb);// RAWParams raw will not be used for non-raw files (see imagesource.h)
-    static void colorSpaceConversion (Imagefloat* im, ColorManagementParams cmp, cmsHPROFILE embedded, IIOSampleFormat sampleFormat);
+    void        convertColorSpace(Imagefloat* image, const ColorManagementParams &cmp, const ColorTemp &wb);// RAWParams raw will not be used for non-raw files (see imagesource.h)
+    static void colorSpaceConversion (Imagefloat* im, const ColorManagementParams &cmp, cmsHPROFILE embedded, IIOSampleFormat sampleFormat);
 
-    static inline double intpow (double a, int b)
-    {
-        double r = 1.0;
-
-        for (int i = 0; i < b; i++) {
-            r *= a;
-        }
-
-        return r;
-    }
-    bool        IsrgbSourceModified()
+    bool        IsrgbSourceModified() const
     {
         return rgbSourceModified;
     }
+    void setCurrentFrame(unsigned int frameNum) {}
+    int getFrameCount() {return 1;}
+
+
+    void getRawValues(int x, int y, int rotate, int &R, int &G, int &B) { R = G = B = 0;}
+
+
 };
 }
 #endif
