@@ -780,6 +780,7 @@ Tag::Tag (TagDirectory* p, FILE* f, int base)
     // (only a small part of it will actually be parsed though)
     if ((int)type < 1 || (int)type > 14 || count > 10 * 1024 * 1024) {
         type = INVALID;
+        valuesize = 0;
         return;
     }
 
@@ -1084,7 +1085,7 @@ defsubdirs:
     // read value
     value = new unsigned char [valuesize];
     fread (value, 1, valuesize, f);
-    int pos = ftell (f);
+
     // count the number of valid subdirs
     int sdcount = count;
 
@@ -1101,7 +1102,6 @@ defsubdirs:
             int newpos = base + toInt (j * 4, LONG);
             fseek (f, newpos, SEEK_SET);
             directory[i] = new TagDirectory (parent, f, base, attrib->subdirAttribs, order);
-            fseek (f, pos, SEEK_SET);
         }
 
         // set the terminating NULL
@@ -1346,7 +1346,9 @@ void Tag::fromString (const char* v, int size)
         value = new unsigned char [valuesize];
     }
 
-    memcpy ((char*)value, v, valuesize);
+    if(value) {
+        memcpy ((char*)value, v, valuesize);
+    }
 }
 
 int Tag::toInt (int ofs, TagType astype)
@@ -1450,7 +1452,6 @@ double Tag::toDouble (int ofs)
             return 0.; // Quick fix for missing cases (INVALID, DOUBLE, OLYUNDEF, SUBDIR)
     }
 
-    return 0.;
 }
 
 /**
@@ -1606,10 +1607,10 @@ void Tag::toString (char* buffer, int ofs)
 std::string Tag::nameToString (int i)
 {
 
-    char buffer[1024];
+    char buffer[1025];
 
     if (attrib) {
-        strcpy (buffer, attrib->name);
+        strncpy (buffer, attrib->name, 1024);
     } else {
         sprintf (buffer, "0x%x", tag);
     }
@@ -1655,17 +1656,15 @@ int Tag::calculateSize ()
         if (j > 1) {
             size += 4 * j;
         }
+        if (makerNoteKind != NOMK) {
+            count = directory[0]->calculateSize () / getTypeSize (type);
+        }
     } else if (valuesize > 4) {
         size += valuesize + (valuesize % 2);    // we align tags to even byte positions
     }
 
-    if (makerNoteKind != NOMK) {
-        count = directory[0]->calculateSize () / getTypeSize (type);
-    }
 
-    if (makerNoteKind == NIKON3 || makerNoteKind == OLYMPUS2 || makerNoteKind == FUJI) {
-        size += valuesize;
-    } else if (makerNoteKind == HEADERIFD) {
+    if (makerNoteKind == NIKON3 || makerNoteKind == OLYMPUS2 || makerNoteKind == FUJI || makerNoteKind == HEADERIFD) {
         size += valuesize;
     }
 
@@ -1913,14 +1912,19 @@ TagDirectory* ExifManager::parseCIFF (FILE* f, int base, int length)
 Tag* ExifManager::saveCIFFMNTag (FILE* f, TagDirectory* root, int len, const char* name)
 {
     int s = ftell (f);
-    char* data = new char [len];
-    fread (data, len, 1, f);
-    TagDirectory* mn = root->getTag ("Exif")->getDirectory()->getTag ("MakerNote")->getDirectory();
-    Tag* cs = new Tag (mn, lookupAttrib (canonAttribs, name));
-    cs->initUndefArray (data, len);
-    mn->addTag (cs);
-    fseek (f, s, SEEK_SET);
-    return cs;
+    if(s >= 0) {
+        char* data = new char [len];
+        fread (data, len, 1, f);
+        TagDirectory* mn = root->getTag ("Exif")->getDirectory()->getTag ("MakerNote")->getDirectory();
+        Tag* cs = new Tag (mn, lookupAttrib (canonAttribs, name));
+        cs->initUndefArray (data, len);
+        mn->addTag (cs);
+        fseek (f, s, SEEK_SET);
+        delete [] data;
+        return cs;
+    } else {
+        return nullptr;
+    }
 }
 
 void ExifManager::parseCIFF (FILE* f, int base, int length, TagDirectory* root)
@@ -2500,6 +2504,8 @@ parse_leafdata (TagDirectory* root, ByteOrder order)
                     if (*p1 != '\0') {
                         t->initInt (atoi (p1), LONG);
                         exif->getDirectory()->addTagFront (t);
+                    } else {
+                        delete t;
                     }
                 } else if (strcmp (tag, "DateTimeOriginal") == 0 &&
                            sscanf (val, "%d-%d-%dT%d:%d:%dZ",
@@ -2734,7 +2740,7 @@ TagDirectory* ExifManager::parse (FILE* f, int base, bool skipIgnored)
         Tag* tmodel4 = root->getTag ("LocalizedCameraModel");
 
         if (tmodel4) {
-            const char *model4 = (tmodel4) ? (const char *)tmodel4->getValue() : "";
+            const char *model4 = (const char *)tmodel4->getValue();
 
             if (strstr (model4, "Hasselblad ") == model4) {
                 model4 = model4 + 11;
@@ -2779,27 +2785,29 @@ TagDirectory* ExifManager::parse (FILE* f, int base, bool skipIgnored)
 TagDirectory* ExifManager::parseJPEG (FILE* f, int offset)
 {
 
-    fseek (f, offset, SEEK_SET);
-    unsigned char markerl = 0xff;
-    unsigned char c;
-    fread (&c, 1, 1, f);
-    const char exifid[] = "Exif\0\0";
-    char idbuff[8];
-    int tiffbase = -1;
+    if(!fseek (f, offset, SEEK_SET)) {
+        unsigned char c;
+        if(fread (&c, 1, 1, f) == 1) {
+            constexpr unsigned char markerl = 0xff;
+            const char exifid[] = "Exif\0\0";
+            char idbuff[8];
+            int tiffbase = -1;
 
-    while (fread (&c, 1, 1, f)) {
-        if (c != markerl) {
-            continue;
-        }
+            while (fread (&c, 1, 1, f)) {
+                if (c != markerl) {
+                    continue;
+                }
 
-        if (fread (&c, 1, 1, f) && c == 0xe1) { // APP1 marker found
-            if (fread (idbuff, 1, 8, f) < 8) {
-                return nullptr;
-            }
+                if (fread (&c, 1, 1, f) && c == 0xe1) { // APP1 marker found
+                    if (fread (idbuff, 1, 8, f) < 8) {
+                        return nullptr;
+                    }
 
-            if (!memcmp (idbuff + 2, exifid, 6)) {  // Exif info found
-                tiffbase = ftell (f);
-                return parse (f, tiffbase);
+                    if (!memcmp (idbuff + 2, exifid, 6)) {  // Exif info found
+                        tiffbase = ftell (f);
+                        return parse (f, tiffbase);
+                    }
+                }
             }
         }
     }
@@ -3108,8 +3116,8 @@ bool extractLensInfo (std::string &fullname, double &minFocal, double &maxFocal,
     maxFocal = 0.0;
     maxApertureAtMinFocal = 0.0;
     maxApertureAtMaxFocal = 0.0;
-    char buffer[1024];
-    strcpy (buffer, fullname.c_str());
+    char buffer[1025];
+    strncpy (buffer, fullname.c_str(), 1024);
     char *pF = strstr (buffer, "f/" );
 
     if ( pF ) {
