@@ -116,6 +116,12 @@ enum {
     ADDSET_RETI_GAM,
     ADDSET_RETI_SLO,
     ADDSET_WB_TEMPBIAS,
+    ADDSET_SHARP_RADIUS,
+    ADDSET_SHARP_DAMPING,
+    ADDSET_SHARP_ITER,
+    ADDSET_SHARP_EDGETOL,
+    ADDSET_SHARP_HALOCTRL,
+    ADDSET_RESIZE_SCALE,
 
     ADDSET_PARAM_NUM // THIS IS USED AS A DELIMITER!!
 };
