@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -24,14 +24,16 @@
 #include "threadutils.h"
 #include "thumbnail.h"
 
-class BQEntryUpdateListener {
+class BQEntryUpdateListener
+{
 
-    public:
-        virtual ~BQEntryUpdateListener () {}
-        virtual void updateImage (guint8* img, int w, int h, int origw, int origh, guint8* newOPreview) {}
+public:
+    virtual ~BQEntryUpdateListener () {}
+    virtual void updateImage (guint8* img, int w, int h, int origw, int origh, guint8* newOPreview) {}
 };
 
-class BatchQueueEntryUpdater {
+class BatchQueueEntryUpdater
+{
 
     struct Job {
         guint8* oimg;
@@ -41,17 +43,17 @@ class BatchQueueEntryUpdater {
         Thumbnail* thumbnail;
     };
 
-  protected:
+protected:
     bool tostop;
     bool stopped;
     std::list<Job> jqueue;
     Glib::Thread* thread;
     MyMutex* qMutex;
 
-  public:
+public:
     BatchQueueEntryUpdater ();
 
-    void process    (guint8* oimg, int ow, int oh, int newh, BQEntryUpdateListener* listener, rtengine::ProcParams* pparams=NULL, Thumbnail* thumbnail=NULL);
+    void process    (guint8* oimg, int ow, int oh, int newh, BQEntryUpdateListener* listener, rtengine::ProcParams* pparams = nullptr, Thumbnail* thumbnail = nullptr);
     void removeJobs (BQEntryUpdateListener* listener);
     void terminate  ();
 
