@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -23,7 +23,8 @@
 using namespace rtengine;
 using namespace rtengine::procparams;
 
-CACorrection::CACorrection () : FoldableToolPanel(this) {
+CACorrection::CACorrection () : FoldableToolPanel(this, "cacorrection", M("TP_CACORRECTION_LABEL"))
+{
 
     Gtk::Image* icaredL =   Gtk::manage (new RTImage ("ajd-ca-red1.png"));
     Gtk::Image* icaredR =   Gtk::manage (new RTImage ("ajd-ca-red2.png"));
@@ -31,10 +32,10 @@ CACorrection::CACorrection () : FoldableToolPanel(this) {
     Gtk::Image* icablueR =  Gtk::manage (new RTImage ("ajd-ca-blue2.png"));
 
     red = Gtk::manage (new Adjuster (M("TP_CACORRECTION_RED"), -0.005, 0.005, 0.0001, 0, icaredL, icaredR));
-    red->setAdjusterListener (this); 
+    red->setAdjusterListener (this);
 
     blue = Gtk::manage (new Adjuster (M("TP_CACORRECTION_BLUE"), -0.005, 0.005, 0.0001, 0, icablueL, icablueR));
-    blue->setAdjusterListener (this); 
+    blue->setAdjusterListener (this);
 
     pack_start (*red);
     pack_start (*blue);
@@ -42,7 +43,8 @@ CACorrection::CACorrection () : FoldableToolPanel(this) {
     show_all();
 }
 
-void CACorrection::read (const ProcParams* pp, const ParamsEdited* pedited) {
+void CACorrection::read (const ProcParams* pp, const ParamsEdited* pedited)
+{
 
     disableListener ();
 
@@ -53,11 +55,12 @@ void CACorrection::read (const ProcParams* pp, const ParamsEdited* pedited) {
 
     red->setValue (pp->cacorrection.red);
     blue->setValue (pp->cacorrection.blue);
-    
+
     enableListener ();
 }
 
-void CACorrection::write (ProcParams* pp, ParamsEdited* pedited) {
+void CACorrection::write (ProcParams* pp, ParamsEdited* pedited)
+{
 
     pp->cacorrection.red  = red->getValue ();
     pp->cacorrection.blue = blue->getValue ();
@@ -68,7 +71,8 @@ void CACorrection::write (ProcParams* pp, ParamsEdited* pedited) {
     }
 }
 
-void CACorrection::setDefaults (const ProcParams* defParams, const ParamsEdited* pedited) {
+void CACorrection::setDefaults (const ProcParams* defParams, const ParamsEdited* pedited)
+{
 
     red->setDefault (defParams->cacorrection.red);
     blue->setDefault (defParams->cacorrection.blue);
@@ -76,32 +80,36 @@ void CACorrection::setDefaults (const ProcParams* defParams, const ParamsEdited*
     if (pedited) {
         red->setDefaultEditedState (pedited->cacorrection.red ? Edited : UnEdited);
         blue->setDefaultEditedState (pedited->cacorrection.blue ? Edited : UnEdited);
-    }
-    else {
+    } else {
         red->setDefaultEditedState (Irrelevant);
         blue->setDefaultEditedState (Irrelevant);
     }
 }
 
-void CACorrection::adjusterChanged (Adjuster* a, double newval) {
+void CACorrection::adjusterChanged (Adjuster* a, double newval)
+{
 
-    if (listener) 
+    if (listener) {
         listener->panelChanged (EvCACorr, Glib::ustring::compose ("%1=%3\n%2=%4", M("TP_CACORRECTION_RED"), M("TP_CACORRECTION_BLUE"), Glib::ustring::format (std::setw(5), std::fixed, std::setprecision(4), red->getValue()), Glib::ustring::format (std::setw(5), std::fixed, std::setprecision(4), blue->getValue())));
+    }
 }
 
-void CACorrection::setAdjusterBehavior (bool badd) {
+void CACorrection::setAdjusterBehavior (bool badd)
+{
 
-	red->setAddMode(badd);
-	blue->setAddMode(badd);
+    red->setAddMode(badd);
+    blue->setAddMode(badd);
 }
 
-void CACorrection::trimValues (rtengine::procparams::ProcParams* pp) {
+void CACorrection::trimValues (rtengine::procparams::ProcParams* pp)
+{
 
-	red->trimValue(pp->cacorrection.red);
-	blue->trimValue(pp->cacorrection.blue);
+    red->trimValue(pp->cacorrection.red);
+    blue->trimValue(pp->cacorrection.blue);
 }
 
-void CACorrection::setBatchMode (bool batchMode) {
+void CACorrection::setBatchMode (bool batchMode)
+{
 
     ToolPanel::setBatchMode (batchMode);
     red->showEditedCB ();
