@@ -131,6 +131,8 @@ void ColoredBar::updateBackBuffer(Gtk::DrawingArea &drawingArea)
         } else {
             // ask the ColorProvider to provide colors :) for each pixels
             if (colorProvider) {
+                surface->flush();
+                
                 unsigned char *surfaceData = surface->get_data();
 
                 cr->set_antialias(Cairo::ANTIALIAS_NONE);
@@ -202,6 +204,8 @@ void ColoredBar::updateBackBuffer(Gtk::DrawingArea &drawingArea)
 
                     break;
                 }
+
+                surface->mark_dirty();
             }
         }
 
