@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -24,28 +24,32 @@
 #include "toolpanel.h"
 #include "lensgeomlistener.h"
 
-class Distortion : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel {
+class Distortion : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel
+{
 
-  protected:
+protected:
     Gtk::Button*   autoDistor;
     Adjuster* distor;
     sigc::connection    idConn;
     LensGeomListener * rlistener;
 
-  public:
+public:
 
     Distortion ();
 
-    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited=NULL); 
-    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited=NULL);
-    void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited=NULL);
+    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited = nullptr);
+    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited = nullptr);
+    void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited = nullptr);
     void setBatchMode   (bool batchMode);
 
     void adjusterChanged     (Adjuster* a, double newval);
     void setAdjusterBehavior (bool vadd);
     void trimValues          (rtengine::procparams::ProcParams* pp);
     void idPressed           ();
-    void setLensGeomListener (LensGeomListener* l) { rlistener = l; }
+    void setLensGeomListener (LensGeomListener* l)
+    {
+        rlistener = l;
+    }
 };
 
 #endif
