@@ -822,7 +822,7 @@ OPIcon::OPIcon(const Cairo::RefPtr<Cairo::ImageSurface> &normal,
     }
 
     if (dragged) {
-        draggedImg = active;
+        draggedImg = dragged;
     }
 
     if (insensitive) {
