@@ -28,11 +28,11 @@
 // Check if the system has more than one display and option is set
 bool EditWindow::isMultiDisplayEnabled()
 {
-    return options.multiDisplayMode > 0 && Gdk::Screen::get_default()->get_n_monitors () > 1;
+    return options.multiDisplayMode > 0 && Gdk::Screen::get_default()->get_n_monitors() > 1;
 }
 
 // Should only be created once, auto-creates window on correct display
-EditWindow* EditWindow::getInstance(RTWindow* p)
+EditWindow* EditWindow::getInstance(RTWindow* p, bool restore)
 {
     struct EditWindowInstance
     {
@@ -40,23 +40,17 @@ EditWindow* EditWindow::getInstance(RTWindow* p)
 
         explicit EditWindowInstance(RTWindow* p) : editWnd(p)
         {
-            // Determine the other display and maximize the window on that
-            const Glib::RefPtr< Gdk::Window >& wnd = p->get_window();
-            int monNo = p->get_screen()->get_monitor_at_window (wnd);
-
-            Gdk::Rectangle lMonitorRect;
-            editWnd.get_screen()->get_monitor_geometry(isMultiDisplayEnabled() ? (monNo == 0 ?  1 : 0) : monNo, lMonitorRect);
-            editWnd.move(lMonitorRect.get_x(), lMonitorRect.get_y());
-            editWnd.maximize();
         }
     };
 
     static EditWindowInstance instance_(p);
-    instance_.editWnd.show_all();
+    if(restore) {
+        instance_.editWnd.restoreWindow();
+    }
     return &instance_.editWnd;
 }
 
-EditWindow::EditWindow (RTWindow* p) : parent(p) , isFullscreen(false)
+EditWindow::EditWindow (RTWindow* p) : parent(p) , isFullscreen(false), isClosed(true)
 {
 
     Glib::ustring fName = "rt-logo-tiny.png";
@@ -71,9 +65,9 @@ EditWindow::EditWindow (RTWindow* p) : parent(p) , isFullscreen(false)
     set_title_decorated("");
     set_modal(false);
     set_resizable(true);
+    set_default_size(options.meowWidth, options.meowHeight);
 
     property_destroy_with_parent().set_value(false);
-    signal_window_state_event().connect( sigc::mem_fun(*this, &EditWindow::on_window_state_event) );
 
     mainNB = Gtk::manage (new Gtk::Notebook ());
     mainNB->set_scrollable (true);
@@ -85,7 +79,46 @@ EditWindow::EditWindow (RTWindow* p) : parent(p) , isFullscreen(false)
     mainBox->pack_start (*mainNB);
 
     add (*mainBox);
-    show_all ();
+
+}
+
+void EditWindow::restoreWindow() {
+
+    if(isClosed) {
+        int meowMonitor = 0;
+        if(isMultiDisplayEnabled()) {
+            if(options.meowMonitor >= 0) { // use display from last session if available
+                meowMonitor = std::min(options.meowMonitor, Gdk::Screen::get_default()->get_n_monitors() - 1);
+            } else { // Determine the other display
+                const Glib::RefPtr< Gdk::Window >& wnd = parent->get_window();
+                meowMonitor = parent->get_screen()->get_monitor_at_window(wnd) == 0 ? 1 : 0;
+            }
+        }
+
+        Gdk::Rectangle lMonitorRect;
+        get_screen()->get_monitor_geometry(meowMonitor, lMonitorRect);
+        if(options.meowMaximized) {
+            move(lMonitorRect.get_x(), lMonitorRect.get_y());
+            maximize();
+        } else {
+            resize(options.meowWidth, options.meowHeight);
+            if(options.meowX <= lMonitorRect.get_x() + lMonitorRect.get_width() && options.meowY <= lMonitorRect.get_y() + lMonitorRect.get_height()) {
+                move(options.meowX, options.meowY);
+            } else {
+                move(lMonitorRect.get_x(), lMonitorRect.get_y());
+            }
+        }
+        show_all();
+
+        isFullscreen = options.meowFullScreen;
+
+        if(isFullscreen) {
+            fullscreen();
+        }
+
+        isClosed = false;
+    }
+
 }
 
 void EditWindow::on_realize ()
@@ -95,19 +128,30 @@ void EditWindow::on_realize ()
     editWindowCursorManager.init (get_window());
 }
 
-bool EditWindow::on_window_state_event(GdkEventWindowState* event)
+bool EditWindow::on_configure_event(GdkEventConfigure* event)
 {
-    if (!event->new_window_state) {
-        // Window mode
-        options.windowMaximized = false;
-    } else if (event->new_window_state & (GDK_WINDOW_STATE_MAXIMIZED | GDK_WINDOW_STATE_FULLSCREEN)) {
-        // Fullscreen mode
-        options.windowMaximized = true;
+    if (get_realized() && is_visible()) {
+        if(!is_maximized()) {
+            get_position(options.meowX, options.meowY);
+            get_size(options.meowWidth, options.meowHeight);
+        }
+        options.meowMaximized = is_maximized();
     }
 
-    return true;
+    return Gtk::Widget::on_configure_event(event);
 }
 
+/*  HOMBRE: Disabling this since it's maximized when opened anyway.
+ *  Someday, the EditorWindow migh save it own position and state, so it'll have to be uncommented
+bool EditWindow::on_window_state_event(GdkEventWindowState* event)
+{
+    if (event->changed_mask & GDK_WINDOW_STATE_MAXIMIZED) {
+        options.windowMaximized = event->new_window_state & GDK_WINDOW_STATE_MAXIMIZED;
+    }
+
+    return Gtk::Widget::on_window_state_event(event);
+}*/
+
 void EditWindow::on_mainNB_switch_page(Gtk::Widget* widget, guint page_num)
 {
     //if (page_num > 1) {
@@ -124,6 +168,7 @@ void EditWindow::on_mainNB_switch_page(Gtk::Widget* widget, guint page_num)
 void EditWindow::addEditorPanel (EditorPanel* ep, const std::string &name)
 {
     ep->setParent (parent);
+    ep->setParentWindow(this);
 
     // construct closeable tab for the image
     Gtk::HBox* hb = Gtk::manage (new Gtk::HBox ());
@@ -190,6 +235,14 @@ bool EditWindow::selectEditorPanel(const std::string &name)
     return false;
 }
 
+void EditWindow::toFront ()
+{
+    // when using the secondary window on the same monitor as the primary window we need to present the secondary window.
+    // If we don't, it will stay in background when opening 2nd, 3rd... editor, which is annoying
+    // It will also deiconify the window
+    present();
+}
+
 bool EditWindow::keyPressed (GdkEventKey* event)
 {
     bool ctrl = event->state & GDK_CONTROL_MASK;
@@ -217,22 +270,70 @@ bool EditWindow::keyPressed (GdkEventKey* event)
 void EditWindow::toggleFullscreen ()
 {
     isFullscreen ? unfullscreen() : fullscreen();
-    isFullscreen = !isFullscreen;
+    options.meowFullScreen = isFullscreen = !isFullscreen;
 }
 
+void EditWindow::writeOptions() {
+
+    if(is_visible()) {
+        if(isMultiDisplayEnabled()) {
+            options.meowMonitor = get_screen()->get_monitor_at_window(get_window());
+        }
+
+        options.meowMaximized = is_maximized();
+        get_position(options.meowX, options.meowY);
+        get_size(options.meowWidth,options.meowHeight);
+    }
+}
 bool EditWindow::on_delete_event(GdkEventAny* event)
 {
-    // Check if any editor is still processing, and do NOT quit if so. Otherwise crashes and inconsistent caches
-    bool isProcessing = false;
 
-    for ( std::set <Glib::ustring>::iterator iter = filesEdited.begin(); iter != filesEdited.end() && !isProcessing; ++iter ) {
+    if (!closeOpenEditors()) {
+        return true;
+    }
+
+    writeOptions();
+    hide();
+    isClosed = true;
+
+    return false;
+}
+
+bool EditWindow::isProcessing ()
+{
+    for ( std::set <Glib::ustring>::iterator iter = filesEdited.begin(); iter != filesEdited.end(); ++iter ) {
         if (epanels[*iter]->getIsProcessing()) {
-            isProcessing = true;
+            return true;
         }
     }
 
-    if (isProcessing) {
-        return true;
+    return false;
+}
+
+bool EditWindow::closeOpenEditors()
+{
+    // Check if any editor is still processing, and do NOT quit if so. Otherwise crashes and inconsistent caches
+    if (isProcessing()) {
+        return false;
+    }
+
+    if (epanels.size()) {
+        int page = mainNB->get_current_page();
+        Gtk::Widget *w = mainNB->get_nth_page(page);
+        bool optionsWritten = false;
+
+        for (std::map<Glib::ustring, EditorPanel*>::iterator i = epanels.begin(); i != epanels.end(); ++i) {
+            if (i->second == w) {
+                i->second->writeOptions();
+                optionsWritten = true;
+            }
+        }
+
+        if (!optionsWritten) {
+            // fallback solution: save the options of the first editor panel
+            std::map<Glib::ustring, EditorPanel*>::iterator i = epanels.begin();
+            i->second->writeOptions();
+        }
     }
 
     for ( std::set <Glib::ustring>::iterator iter = filesEdited.begin(); iter != filesEdited.end(); ++iter ) {
@@ -240,12 +341,10 @@ bool EditWindow::on_delete_event(GdkEventAny* event)
     }
 
     epanels.clear();
-
     filesEdited.clear();
     parent->fpanel->refreshEditedState (filesEdited);
 
-    hide ();
-    return false;
+    return true;
 }
 
 void EditWindow::set_title_decorated(Glib::ustring fname)
