@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -23,28 +23,26 @@
 #include "adjuster.h"
 #include "toolpanel.h"
 
-class EdgePreservingDecompositionUI : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel {
+class EdgePreservingDecompositionUI : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel
+{
 protected:
-	Adjuster *strength;
-	Adjuster *edgeStopping;
-	Adjuster *scale;
-	Adjuster *reweightingIterates;
-
-	Gtk::CheckButton* enabled;
-	bool lastEnabled;
-	sigc::connection enaConn;
+    Adjuster *strength;
+    Adjuster *gamma;
+    Adjuster *edgeStopping;
+    Adjuster *scale;
+    Adjuster *reweightingIterates;
 
 public:
 
-	EdgePreservingDecompositionUI();
+    EdgePreservingDecompositionUI();
 
-	void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited=NULL); 
-	void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited=NULL);
-	void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited=NULL);
-	void setBatchMode   (bool batchMode);
+    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited = nullptr);
+    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited = nullptr);
+    void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited = nullptr);
+    void setBatchMode   (bool batchMode);
 
-	void adjusterChanged (Adjuster* a, double newval);
-	void enabledChanged  ();
+    void adjusterChanged (Adjuster* a, double newval);
+    void enabledChanged  ();
 };
 
 #endif
