@@ -38,7 +38,7 @@ Glib::RefPtr<Gdk::Pixbuf> FileBrowserEntry::recentlySavedIcon;
 Glib::RefPtr<Gdk::Pixbuf> FileBrowserEntry::enqueuedIcon;
 
 FileBrowserEntry::FileBrowserEntry (Thumbnail* thm, const Glib::ustring& fname)
-    : ThumbBrowserEntryBase (fname), wasInside(false), iatlistener(nullptr), cropgl(nullptr), state(SNormal), crop_custom_ratio(0.f)
+    : ThumbBrowserEntryBase (fname), wasInside(false), iatlistener(nullptr), press_x(0), press_y(0), action_x(0), action_y(0), rot_deg(0.0), landscape(true), cropgl(nullptr), state(SNormal), crop_custom_ratio(0.f)
 {
     thumbnail = thm;
 
@@ -60,9 +60,7 @@ FileBrowserEntry::FileBrowserEntry (Thumbnail* thm, const Glib::ustring& fname)
         iconsLoaded = true;
     }
 
-    if (thm) {
-        thm->addThumbnailListener (this);
-    }
+    thumbnail->addThumbnailListener (this);
 }
 
 FileBrowserEntry::~FileBrowserEntry ()
@@ -207,11 +205,7 @@ void FileBrowserEntry::updateImage (rtengine::IImage8* img, double scale, rtengi
         cropParams
     };
 
-#if __GNUC__ == 4 && __GNUC_MINOR__ == 8 && defined( WIN32 ) && defined(__x86_64__)
-    const gint priority = G_PRIORITY_DEFAULT;
-#else
     const gint priority = G_PRIORITY_LOW;
-#endif
 
     const auto func = [](gpointer data) -> gboolean {
         tiupdate* const params = static_cast<tiupdate*>(data);
