@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -21,9 +21,10 @@
 
 #include "thumbnail.h"
 
-class FileSelectionChangeListener {
+class FileSelectionChangeListener
+{
 
-  public:
+public:
     virtual void selectionChanged       (const std::vector<Thumbnail*>& selected) {}
 };
 
