@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -22,11 +22,12 @@
 #include "thumbnail.h"
 #include "batchqueueentry.h"
 
-class FileSelectionListener {
+class FileSelectionListener
+{
 
-  public:
-    virtual bool fileSelected           (Thumbnail* thm) =0;
-    virtual bool addBatchQueueJobs      ( std::vector<BatchQueueEntry*> &entries ) =0;
+public:
+    virtual bool fileSelected           (Thumbnail* thm) = 0;
+    virtual bool addBatchQueueJobs      ( std::vector<BatchQueueEntry*> &entries ) = 0;
 };
 
 #endif
