@@ -19,7 +19,6 @@
 #include "flatfield.h"
 #include "options.h"
 #include "guiutils.h"
-#include "../rtengine/safegtk.h"
 #include <sstream>
 #include "rtimage.h"
 
@@ -54,10 +53,10 @@ FlatField::FlatField () : FoldableToolPanel(this, "flatfield", M("TP_FLATFIELD_L
     hbffbt->pack_start (*Gtk::manage (new Gtk::Label ( M("TP_FLATFIELD_BLURTYPE") + ":")));
     hbffbt->set_spacing(4);
     flatFieldBlurType = Gtk::manage (new MyComboBoxText ());
-    flatFieldBlurType->append_text(M("TP_FLATFIELD_BT_AREA"));
-    flatFieldBlurType->append_text(M("TP_FLATFIELD_BT_VERTICAL"));
-    flatFieldBlurType->append_text(M("TP_FLATFIELD_BT_HORIZONTAL"));
-    flatFieldBlurType->append_text(M("TP_FLATFIELD_BT_VERTHORIZ"));
+    flatFieldBlurType->append(M("TP_FLATFIELD_BT_AREA"));
+    flatFieldBlurType->append(M("TP_FLATFIELD_BT_VERTICAL"));
+    flatFieldBlurType->append(M("TP_FLATFIELD_BT_HORIZONTAL"));
+    flatFieldBlurType->append(M("TP_FLATFIELD_BT_VERTHORIZ"));
     flatFieldBlurType->set_active(0);
     hbffbt->pack_end (*flatFieldBlurType);
 
@@ -87,19 +86,19 @@ FlatField::FlatField () : FoldableToolPanel(this, "flatfield", M("TP_FLATFIELD_L
 
     // Set filename filters
     b_filter_asCurrent = false;
-    Gtk::FileFilter *filter_any = Gtk::manage(new Gtk::FileFilter);
+    Glib::RefPtr<Gtk::FileFilter> filter_any = Gtk::FileFilter::create();
     filter_any->add_pattern("*");
     filter_any->set_name(M("FILECHOOSER_FILTER_ANY"));
-    flatFieldFile->add_filter (*filter_any);
+    flatFieldFile->add_filter (filter_any);
 
     // filters for all supported non-raw extensions
     for (size_t i = 0; i < options.parseExtensions.size(); i++) {
         if (options.parseExtensionsEnabled[i] && options.parseExtensions[i].uppercase() != "JPG" && options.parseExtensions[i].uppercase() != "JPEG" && options.parseExtensions[i].uppercase() != "PNG" && options.parseExtensions[i].uppercase() != "TIF" && options.parseExtensions[i].uppercase() != "TIFF"  ) {
-            Gtk::FileFilter *filter_ff = Gtk::manage(new Gtk::FileFilter);
+            Glib::RefPtr<Gtk::FileFilter> filter_ff = Gtk::FileFilter::create();
             filter_ff->add_pattern("*." + options.parseExtensions[i]);
             filter_ff->add_pattern("*." + options.parseExtensions[i].uppercase());
             filter_ff->set_name(options.parseExtensions[i].uppercase());
-            flatFieldFile->add_filter (*filter_ff);
+            flatFieldFile->add_filter (filter_ff);
             //printf("adding filter %s \n",options.parseExtensions[i].uppercase().c_str());
         }
     }
@@ -140,7 +139,7 @@ void FlatField::read(const rtengine::procparams::ProcParams* pp, const ParamsEdi
         }
     }
 
-    if (safe_file_test (pp->raw.ff_file, Glib::FILE_TEST_EXISTS)) {
+    if (Glib::file_test (pp->raw.ff_file, Glib::FILE_TEST_EXISTS)) {
         flatFieldFile->set_filename (pp->raw.ff_file);
     } else {
         flatFieldFile_Reset();
@@ -175,8 +174,8 @@ void FlatField::read(const rtengine::procparams::ProcParams* pp, const ParamsEdi
 
         if (b_filter_asCurrent) {
             //First, remove last filter_asCurrent if it was set for a raw file
-            std::vector<const Gtk::FileFilter*> filters = flatFieldFile->list_filters();
-            flatFieldFile->remove_filter(**(filters.end() - 1));
+            std::vector< Glib::RefPtr<Gtk::FileFilter> > filters = flatFieldFile->list_filters();
+            flatFieldFile->remove_filter(*(filters.end() - 1));
             b_filter_asCurrent = false;
         }
 
@@ -195,11 +194,11 @@ void FlatField::read(const rtengine::procparams::ProcParams* pp, const ParamsEdi
 
                 if (israw) {
                     b_filter_asCurrent = true; //prevent re-adding this filter on every pp3 file read
-                    Gtk::FileFilter *filter_asCurrent = Gtk::manage(new Gtk::FileFilter);
+                    Glib::RefPtr<Gtk::FileFilter> filter_asCurrent = Gtk::FileFilter::create();
                     filter_asCurrent->add_pattern("*." + filetype);
                     filter_asCurrent->set_name(M("FILECHOOSER_FILTER_SAME") + " (" + filetype + ")");
-                    flatFieldFile->add_filter (*filter_asCurrent);
-                    flatFieldFile->set_filter (*filter_asCurrent);
+                    flatFieldFile->add_filter (filter_asCurrent);
+                    flatFieldFile->set_filter (filter_asCurrent);
                 }
             }
         }
@@ -392,28 +391,21 @@ void FlatField::flatFieldAutoSelectChanged()
 
 }
 
-void FlatField::setShortcutPath(Glib::ustring path)
+void FlatField::setShortcutPath(const Glib::ustring& path)
 {
-    if (path == "") {
+    if (path.empty ()) {
         return;
     }
 
-#ifdef WIN32
+    try {
 
-    // Dirty workaround, waiting for a clean solution by using exceptions!
-    if (!safe_is_shortcut_dir(path))
-#endif
-    {
-        if (lastShortcutPath != "") {
-            try {
-                flatFieldFile->remove_shortcut_folder(lastShortcutPath);
-            } catch (Glib::Error &err) {}
+        if (!lastShortcutPath.empty ()) {
+            flatFieldFile->remove_shortcut_folder (lastShortcutPath);
         }
 
+        flatFieldFile->add_shortcut_folder (path);
+
         lastShortcutPath = path;
 
-        try {
-            flatFieldFile->add_shortcut_folder(path);
-        } catch (Glib::Error &err) {}
-    }
+    } catch (Glib::Error&) {}
 }
