@@ -8,15 +8,16 @@
 #include "adjuster.h"
 #include "toolpanel.h"
 #include "edit.h"
+#include "guiutils.h"
 
-class Gradient : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel, public EditSubscriber {
+class Gradient : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel, public EditSubscriber
+{
 
-  private:
+private:
     int lastObject;
-    Gtk::HBox* enaBox;
 
-  protected:
-    Gtk::CheckButton* enabled;
+protected:
+    Gtk::HBox *editHBox;
     Gtk::ToggleButton* edit;
     Adjuster* degree;
     Adjuster* feather;
@@ -26,37 +27,35 @@ class Gradient : public ToolParamBlock, public AdjusterListener, public Foldable
     double draggedPointOldAngle;
     double draggedPointAdjusterAngle;
     double draggedFeatherOffset;
-    Coord draggedCenter;
-    bool lastEnabled;
-    sigc::connection enaConn, editConn;
+    rtengine::Coord draggedCenter;
+    sigc::connection editConn;
 
     void editToggled ();
 
-  public:
+public:
 
     Gradient ();
     ~Gradient ();
 
-    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited=NULL); 
-    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited=NULL);
-    void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited=NULL);
+    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited = nullptr);
+    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited = nullptr);
+    void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited = nullptr);
     void setBatchMode   (bool batchMode);
 
-    void updateGeometry (int centerX_, int centerY_, double feather_, double degree_);
-
     void adjusterChanged (Adjuster* a, double newval);
-    void enabledChanged ();
+    void enabledChanged  ();
     void setAdjusterBehavior (bool degreeadd, bool featheradd, bool strengthadd, bool centeradd);
     void trimValues          (rtengine::procparams::ProcParams* pp);
+    void updateGeometry  (const int centerX, const int centerY, const double feather, const double degree, const int fullWidth=-1, const int fullHeight=-1);
 
     void setEditProvider (EditDataProvider* provider);
 
     // EditSubscriber interface
-    CursorShape getCursor(int objectID);
-    bool mouseOver(int modifierKey);
-    bool button1Pressed(int modifierKey);
+    CursorShape getCursor(const int objectID);
+    bool mouseOver(const int modifierKey);
+    bool button1Pressed(const int modifierKey);
     bool button1Released();
-    bool drag(int modifierKey);
+    bool drag1(const int modifierKey);
     void switchOffEditMode ();
 };
 
