@@ -33,7 +33,7 @@
 #include "edit.h"
 
 class ImageAreaPanel;
-class ImageArea : public Gtk::DrawingArea, public CropWindowListener, public EditDataProvider
+class ImageArea : public Gtk::DrawingArea, public CropWindowListener, public EditDataProvider, public LockablePickerToolListener
 {
 
     friend class ZoomPanel;
@@ -41,9 +41,8 @@ class ImageArea : public Gtk::DrawingArea, public CropWindowListener, public Edi
 protected:
 
     Glib::ustring infotext;
-    Glib::RefPtr<Pango::Layout> ilayout;
     Glib::RefPtr<Pango::Layout> deglayout;
-    Glib::RefPtr<Gdk::Pixbuf>   ipixbuf;
+    BackBuffer iBackBuffer;
     bool showClippedH, showClippedS;
 
     ImageAreaPanel* parent;
@@ -60,6 +59,12 @@ protected:
     ImageAreaToolListener* listener;
 
     CropWindow* getCropWindow (int x, int y);
+    Gtk::SizeRequestMode get_request_mode_vfunc () const;
+    void get_preferred_height_vfunc (int &minimum_height, int &natural_height) const;
+    void get_preferred_width_vfunc (int &minimum_width, int &natural_width) const;
+    void get_preferred_height_for_width_vfunc (int width, int &minimum_height, int &natural_height) const;
+    void get_preferred_width_for_height_vfunc (int height, int &minimum_width, int &natural_width) const;
+
     bool firstOpen;
     int fullImageWidth, fullImageHeight;
 public:
@@ -70,10 +75,11 @@ public:
     PreviewModePanel* previewModePanel;
     ImageArea* iLinkedImageArea; // used to set a reference to the Before image area, which is set when before/after view is enabled
 
-    ImageArea (ImageAreaPanel* p);
+    explicit ImageArea (ImageAreaPanel* p);
     ~ImageArea ();
 
-    void setImProcCoordinator (rtengine::StagedImageProcessor* ipc_);
+    rtengine::StagedImageProcessor* getImProcCoordinator() const;
+    void setImProcCoordinator(rtengine::StagedImageProcessor* ipc_);
     void setPreviewModePanel(PreviewModePanel* previewModePanel_)
     {
         previewModePanel = previewModePanel_;
@@ -93,14 +99,14 @@ public:
 
     // widget base events
     void on_realize ();
-    bool on_expose_event         (GdkEventExpose* event);
+    bool on_draw                 (const ::Cairo::RefPtr< Cairo::Context> &cr);
     bool on_motion_notify_event  (GdkEventMotion* event);
     bool on_button_press_event   (GdkEventButton* event);
     bool on_button_release_event (GdkEventButton* event);
     bool on_scroll_event         (GdkEventScroll* event);
     bool on_leave_notify_event   (GdkEventCrossing* event);
     void on_resized              (Gtk::Allocation& req);
-    void on_style_changed        (const Glib::RefPtr<Gtk::Style>& style);
+    void on_style_updated        ();
     void syncBeforeAfterViews    ();
 
     void            setCropGUIListener       (CropGUIListener* l);
@@ -122,6 +128,7 @@ public:
     void cropWindowSelected (CropWindow* cw);
     void cropWindowClosed   (CropWindow* cw);
     ToolMode getToolMode    ();
+    bool showColorPickers   ();
     void setToolHand        ();
     void straightenReady    (double rotDeg);
     void spotWBSelected     (int x, int y);
@@ -143,6 +150,9 @@ public:
     void cropZoomChanged       (CropWindow* cw);
     void initialImageArrived   (CropWindow* cw) ;
 
+    // LockablePickerToolListener interface
+    void switchPickerVisibility (bool isVisible);
+
     CropWindow* getMainCropWindow ()
     {
         return mainCropWindow;
