@@ -25,24 +25,34 @@ class IndicateClippedPanel : public Gtk::HBox
 {
 
 protected:
-    Gtk::ToggleButton* indclippedh;
-    Gtk::ToggleButton* indclippeds;
+    Gtk::Image* iFon, *iFoff;
+    Gtk::ToggleButton* previewFocusMask;
+    Gtk::ToggleButton* indClippedH;
+    Gtk::ToggleButton* indClippedS;
     ImageArea* imageArea;
 
 public:
-    IndicateClippedPanel (ImageArea* ia);
+    explicit IndicateClippedPanel(ImageArea* ia);
+    ~IndicateClippedPanel();
 
-    void buttonToggled   ();
+    void buttonToggled(Gtk::ToggleButton* tb);
+    void toggleClipped(bool highlights);  // inverts a toggle programmatically
+    void toggleFocusMask();
 
-    void toggleClipped (bool highlights);  // inverts a toggle programmatically
+    sigc::connection connFocusMask, connClippedS, connClippedH;
 
-    bool showClippedShadows    ()
+
+    bool showFocusMask ()
     {
-        return indclippeds->get_active ();
+        return previewFocusMask->get_active ();
     }
-    bool showClippedHighlights ()
+    bool showClippedShadows()
     {
-        return indclippedh->get_active ();
+        return indClippedS->get_active();
+    }
+    bool showClippedHighlights()
+    {
+        return indClippedH->get_active();
     }
 };
 
