@@ -19,12 +19,13 @@
 #ifndef _LENSGEOMLISTENER_H_
 #define _LENSGEOMLISTENER_H_
 
-class LensGeomListener {
+class LensGeomListener
+{
 
-    public:
-        virtual void straightenRequested ()=0;
-        virtual void autoCropRequested   ()=0;
-        virtual double autoDistorRequested ()=0;
+public:
+    virtual void straightenRequested () = 0;
+    virtual void autoCropRequested   () = 0;
+    virtual double autoDistorRequested () = 0;
 };
 
 #endif
