@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -20,31 +20,38 @@
 #define _MULTILANGMGR_
 
 #include <map>
+#include <memory>
 #include <string>
-#include <glibmm.h>
 
-class MultiLangMgr {
+#include <glibmm/ustring.h>
 
-    std::map<std::string, Glib::ustring> transTable;
-    MultiLangMgr* fallBack;
-    
-    Glib::ustring TranslateRFC2Language(Glib::ustring rfcName);
+class MultiLangMgr
+{
+public:
+    MultiLangMgr ();
+    MultiLangMgr (const Glib::ustring& fname, MultiLangMgr* fallbackMgr = nullptr);
 
-    public: 
-    MultiLangMgr () : fallBack (NULL) {}
-    MultiLangMgr (Glib::ustring fname) : fallBack (NULL) { load (fname); }
-    MultiLangMgr (Glib::ustring fname, MultiLangMgr* fb) : fallBack (NULL) { load (fname, fb); }
+public:
+    bool load (const Glib::ustring& fname, MultiLangMgr* fallbackMgr = nullptr);
 
-    bool load (Glib::ustring fname, MultiLangMgr* fb = NULL);
-    bool save (Glib::ustring fname);
+public:
+    Glib::ustring getStr (const std::string& key) const;
+
+public:
+    static bool isOSLanguageDetectSupported ();
+    static Glib::ustring getOSUserLanguage ();
+
+private:
+    std::map<std::string, Glib::ustring> translations;
+    std::unique_ptr<MultiLangMgr> fallbackMgr;
 
-    bool isOSLanguageDetectSupported();
-    Glib::ustring getOSUserLanguage();
-    Glib::ustring getStr (std::string key);
 };
 
 extern MultiLangMgr langMgr;
 
-Glib::ustring M (std::string key);
+inline Glib::ustring M (const std::string& key)
+{
+    return langMgr.getStr (key);
+}
 
 #endif
