@@ -101,8 +101,6 @@ public:
     Gtk::CheckButton* raw_black;
     Gtk::CheckButton* raw_ca_autocorrect;
     Gtk::CheckButton* raw_caredblue;
-    Gtk::CheckButton* raw_cablue;
-    Gtk::CheckButton* raw_caautostrength;
     Gtk::CheckButton* raw_hotpix_filt;
     Gtk::CheckButton* raw_deadpix_filt;
     Gtk::CheckButton* raw_linenoise;
@@ -132,7 +130,7 @@ public:
     sigc::connection coarserotConn, finerotConn, cropConn, resizeConn, prsharpeningConn, perspectiveConn, commonTransConn;
     sigc::connection exifchConn, iptcConn, icmConn;
     sigc::connection df_fileConn, df_AutoSelectConn, ff_fileConn, ff_AutoSelectConn, ff_BlurRadiusConn, ff_BlurTypeConn, ff_ClipControlConn;
-    sigc::connection raw_caredblueConn, raw_caautostrengthConn, raw_ca_autocorrectConn, raw_hotpix_filtConn, raw_deadpix_filtConn, raw_linenoiseConn, raw_greenthreshConn, raw_ccStepsConn, raw_methodConn, raw_imagenumConn, raw_dcb_iterationsConn, raw_lmmse_iterationsConn, raw_pixelshiftConn, raw_dcb_enhanceConn, raw_exposConn, raw_preserConn, raw_blackConn;
+    sigc::connection raw_caredblueConn, raw_ca_autocorrectConn, raw_hotpix_filtConn, raw_deadpix_filtConn, raw_linenoiseConn, raw_greenthreshConn, raw_ccStepsConn, raw_methodConn, raw_imagenumConn, raw_dcb_iterationsConn, raw_lmmse_iterationsConn, raw_pixelshiftConn, raw_dcb_enhanceConn, raw_exposConn, raw_preserConn, raw_blackConn;
 
 public:
     PartialPasteDlg (const Glib::ustring &title, Gtk::Window* parent);
