@@ -42,7 +42,9 @@ class PopUpCommon
 
 public:
     typedef sigc::signal<void, int> type_signal_changed;
+    typedef sigc::signal<void, int> type_signal_item_selected;
     type_signal_changed signal_changed();
+    type_signal_item_selected signal_item_selected();
     Gtk::Grid* buttonGroup;    // this is the widget to be packed
 
     PopUpCommon (Gtk::Button* button, const Glib::ustring& label = "");
@@ -57,7 +59,8 @@ public:
     void setItemSensitivity (int i, bool isSensitive);
 
 private:
-    type_signal_changed message;
+    type_signal_changed messageChanged;
+    type_signal_item_selected messageItemSelected;
 
     std::vector<Glib::ustring> imageFilenames;
     std::vector<const RTImage*> images;
@@ -78,7 +81,12 @@ protected:
 
 inline PopUpCommon::type_signal_changed PopUpCommon::signal_changed ()
 {
-    return message;
+    return messageChanged;
+}
+
+inline PopUpCommon::type_signal_item_selected PopUpCommon::signal_item_selected ()
+{
+    return messageItemSelected;
 }
 
 inline int PopUpCommon::getEntryCount () const
