@@ -19,11 +19,15 @@
 #ifndef _PREVIEWHANDLER_
 #define _PREVIEWHANDLER_
 
-#include "../rtengine/rtengine.h"
-#include "threadutils.h"
-#include <gtkmm.h>
 #include <list>
 
+#include <gtkmm.h>
+
+#include "threadutils.h"
+#include "guiutils.h"
+
+#include "../rtengine/rtengine.h"
+
 class PreviewListener
 {
 
@@ -41,11 +45,13 @@ struct PreviewHandlerIdleHelper {
 
 class PreviewHandler : public rtengine::PreviewImageListener
 {
-
+private:
     friend int setImageUI   (void* data);
     friend int delImageUI   (void* data);
     friend int imageReadyUI (void* data);
 
+    IdleRegister idle_register;
+
 protected:
     rtengine::IImage8* image;
     rtengine::procparams::CropParams cropParams;
