@@ -28,19 +28,19 @@ PreviewModePanel::PreviewModePanel (ImageArea* ia) : imageArea(ia)
     iG  = new RTImage ("previewmodeG-on.png");
     iB  = new RTImage ("previewmodeB-on.png");
     iL  = new RTImage ("previewmodeL-on.png");
-    iF  = new RTImage ("previewmodeF-on.png");
     iBC0 = new RTImage ("previewmodeBC0-on.png");
     iBC1 = new RTImage ("previewmodeBC1-on.png");
     iBC2 = new RTImage ("previewmodeBC2-on.png");
+    iBC3 = new RTImage ("previewmodeBC3-on.png");
 
     igR = new RTImage ("previewmodeR-off.png");
     igG = new RTImage ("previewmodeG-off.png");
     igB = new RTImage ("previewmodeB-off.png");
     igL = new RTImage ("previewmodeL-off.png");
-    igF = new RTImage ("previewmodeF-off.png");
     igBC0 = new RTImage ("previewmodeBC0-off.png");
     igBC1 = new RTImage ("previewmodeBC1-off.png");
     igBC2 = new RTImage ("previewmodeBC2-off.png");
+    igBC3 = new RTImage ("previewmodeBC3-off.png");
 
     backColor0 = Gtk::manage (new Gtk::ToggleButton ());
     backColor0->set_relief(Gtk::RELIEF_NONE);
@@ -52,6 +52,11 @@ PreviewModePanel::PreviewModePanel (ImageArea* ia) : imageArea(ia)
     backColor1->set_tooltip_markup (M("MAIN_TOOLTIP_BACKCOLOR1"));
     backColor1->set_image(options.bgcolor == 1 ? *iBC1 : *igBC1);
 
+    backColor3 = Gtk::manage (new Gtk::ToggleButton ());
+    backColor3->set_relief(Gtk::RELIEF_NONE);
+    backColor3->set_tooltip_markup (M("MAIN_TOOLTIP_BACKCOLOR3"));
+    backColor3->set_image(options.bgcolor == 3 ? *iBC3 : *igBC3);
+
     backColor2 = Gtk::manage (new Gtk::ToggleButton ());
     backColor2->set_relief(Gtk::RELIEF_NONE);
     backColor2->set_tooltip_markup (M("MAIN_TOOLTIP_BACKCOLOR2"));
@@ -77,42 +82,37 @@ PreviewModePanel::PreviewModePanel (ImageArea* ia) : imageArea(ia)
     previewL->set_tooltip_markup (M("MAIN_TOOLTIP_PREVIEWL"));
     previewL->set_image(*igL);
 
-    previewFocusMask = Gtk::manage (new Gtk::ToggleButton ());
-    previewFocusMask->set_relief(Gtk::RELIEF_NONE);
-    previewFocusMask->set_tooltip_markup (M("MAIN_TOOLTIP_PREVIEWFOCUSMASK"));
-    previewFocusMask->set_image(*igF);
-
     previewR->set_active (false);
     previewG->set_active (false);
     previewB->set_active (false);
     previewL->set_active (false);
-    previewFocusMask->set_active (false);
 
     backColor0->set_active (options.bgcolor == 0);
     backColor1->set_active (options.bgcolor == 1);
     backColor2->set_active (options.bgcolor == 2);
+    backColor3->set_active (options.bgcolor == 3);
 
-    vbbackColor = Gtk::manage (new Gtk::VBox ());
-    vbbackColor->pack_start (*backColor0, Gtk::PACK_SHRINK, 0);
-    vbbackColor->pack_start (*backColor1, Gtk::PACK_SHRINK, 0);
-    vbbackColor->pack_start (*backColor2, Gtk::PACK_SHRINK, 0);
-    pack_start (*vbbackColor, Gtk::PACK_SHRINK, 0);
+    pack_start (*backColor0, Gtk::PACK_SHRINK, 0);
+    pack_start (*backColor1, Gtk::PACK_SHRINK, 0);
+    pack_start (*backColor3, Gtk::PACK_SHRINK, 0);
+    pack_start (*backColor2, Gtk::PACK_SHRINK, 0);
+
+    pack_start (*Gtk::manage (new Gtk::VSeparator ()), Gtk::PACK_SHRINK, 2);
 
     pack_start (*previewR, Gtk::PACK_SHRINK, 0);
     pack_start (*previewG, Gtk::PACK_SHRINK, 0);
     pack_start (*previewB, Gtk::PACK_SHRINK, 0);
     pack_start (*previewL, Gtk::PACK_SHRINK, 0);
-    pack_start (*previewFocusMask, Gtk::PACK_SHRINK, 0);
 
     connR = previewR->signal_toggled().connect( sigc::bind(sigc::mem_fun(*this, &PreviewModePanel::buttonToggled), previewR) );
     connG = previewG->signal_toggled().connect( sigc::bind(sigc::mem_fun(*this, &PreviewModePanel::buttonToggled), previewG) );
     connB = previewB->signal_toggled().connect( sigc::bind(sigc::mem_fun(*this, &PreviewModePanel::buttonToggled), previewB) );
     connL = previewL->signal_toggled().connect( sigc::bind(sigc::mem_fun(*this, &PreviewModePanel::buttonToggled), previewL) );
-    connFocusMask = previewFocusMask->signal_toggled().connect( sigc::bind(sigc::mem_fun(*this, &PreviewModePanel::buttonToggled), previewFocusMask) );
 
     connbackColor0 = backColor0->signal_toggled().connect( sigc::bind(sigc::mem_fun(*this, &PreviewModePanel::buttonToggled_backColor), backColor0) );
     connbackColor1 = backColor1->signal_toggled().connect( sigc::bind(sigc::mem_fun(*this, &PreviewModePanel::buttonToggled_backColor), backColor1) );
     connbackColor2 = backColor2->signal_toggled().connect( sigc::bind(sigc::mem_fun(*this, &PreviewModePanel::buttonToggled_backColor), backColor2) );
+    connbackColor3 = backColor3->signal_toggled().connect( sigc::bind(sigc::mem_fun(*this, &PreviewModePanel::buttonToggled_backColor), backColor3) );
 
     //show_all ();
 }
@@ -123,18 +123,18 @@ PreviewModePanel::~PreviewModePanel ()
     delete iG;
     delete iB;
     delete iL;
-    delete iF;
     delete iBC0;
     delete iBC1;
     delete iBC2;
+    delete iBC3;
     delete igR;
     delete igG;
     delete igB;
     delete igL;
-    delete igF;
     delete igBC0;
     delete igBC1;
     delete igBC2;
+    delete igBC3;
 }
 //toggle Functions below are for shortcuts
 void PreviewModePanel::toggleR ()
@@ -153,10 +153,6 @@ void PreviewModePanel::toggleL ()
 {
     previewL->set_active(!previewL->get_active());
 }
-void PreviewModePanel::toggleFocusMask ()
-{
-    previewFocusMask->set_active(!previewFocusMask->get_active());
-}
 
 void PreviewModePanel::togglebackColor0 ()
 {
@@ -170,6 +166,10 @@ void PreviewModePanel::togglebackColor2 ()
 {
     backColor2->set_active(!backColor2->get_active());
 }
+void PreviewModePanel::togglebackColor3 ()
+{
+    backColor3->set_active(!backColor3->get_active());
+}
 
 void PreviewModePanel::buttonToggled (Gtk::ToggleButton* tbpreview)
 {
@@ -178,7 +178,6 @@ void PreviewModePanel::buttonToggled (Gtk::ToggleButton* tbpreview)
     connG.block(true);
     connB.block(true);
     connL.block(true);
-    connFocusMask.block(true);
 
     // control state of the buttons
     // only 0 or 1 button at a time can remain pressed
@@ -198,22 +197,16 @@ void PreviewModePanel::buttonToggled (Gtk::ToggleButton* tbpreview)
         previewL->set_active(false);
     }
 
-    if (tbpreview != previewFocusMask) {
-        previewFocusMask->set_active(false);
-    }
-
     // set image based on button's state
     previewR->set_image(previewR->get_active() ? *iR : *igR);
     previewG->set_image(previewG->get_active() ? *iG : *igG);
     previewB->set_image(previewB->get_active() ? *iB : *igB);
     previewL->set_image(previewL->get_active() ? *iL : *igL);
-    previewFocusMask->set_image(previewFocusMask->get_active() ? *iF : *igF);
 
     connR.block(false);
     connG.block(false);
     connB.block(false);
     connL.block(false);
-    connFocusMask.block(false);
 
     imageArea->queue_draw ();
 
@@ -240,6 +233,10 @@ int PreviewModePanel::GetbackColor()
         backColor = 2;
     }
 
+    if (backColor3->get_active ()) {
+        backColor = 3;
+    }
+
     return backColor;
 }
 
@@ -250,6 +247,8 @@ void PreviewModePanel::togglebackColor()
     if(backColor == 0) {
         togglebackColor1();
     } else if(backColor == 1) {
+        togglebackColor3();
+    } else if(backColor == 3) {
         togglebackColor2();
     } else {
         togglebackColor0();
@@ -262,6 +261,7 @@ void PreviewModePanel::buttonToggled_backColor (Gtk::ToggleButton* tbbackColor)
     connbackColor0.block(true);
     connbackColor1.block(true);
     connbackColor2.block(true);
+    connbackColor3.block(true);
 
     // control the state of the buttons
     // Exactly 1 button at a time must remain pressed
@@ -277,6 +277,10 @@ void PreviewModePanel::buttonToggled_backColor (Gtk::ToggleButton* tbbackColor)
         backColor2->set_active(true);
     }
 
+    if (tbbackColor == backColor3 && !backColor3->get_active()) {
+        backColor3->set_active(true);
+    }
+
     if (tbbackColor != backColor0) {
         backColor0->set_active(false);
     }
@@ -289,14 +293,20 @@ void PreviewModePanel::buttonToggled_backColor (Gtk::ToggleButton* tbbackColor)
         backColor2->set_active(false);
     }
 
+    if (tbbackColor != backColor3) {
+        backColor3->set_active(false);
+    }
+
     // set image based on button's state
     backColor0->set_image(backColor0->get_active() ? *iBC0 : *igBC0);
     backColor1->set_image(backColor1->get_active() ? *iBC1 : *igBC1);
     backColor2->set_image(backColor2->get_active() ? *iBC2 : *igBC2);
+    backColor3->set_image(backColor3->get_active() ? *iBC3 : *igBC3);
 
     connbackColor0.block(false);
     connbackColor1.block(false);
     connbackColor2.block(false);
+    connbackColor3.block(false);
 
     //TODO not sure if queue_draw is necessary, but will need to reach to backColor of the Before view
     imageArea->queue_draw ();
