@@ -42,6 +42,8 @@ private:
     RTImage *profileFillModeOffImage;
     Gtk::ToggleButton* fillMode;
     Gtk::TreeIter currRow;
+    ProfileStoreEntry *lastSavedPSE;
+    ProfileStoreEntry *customPSE;
 
     void          profileFillModeToggled ();
     bool          isCustomSelected ();
