@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -20,27 +20,34 @@
 #define _RECENTBROWSER_
 
 #include <gtkmm.h>
-#include "dirbrowserremoteinterface.h"
-#include "dirselectionlistener.h"
 #include "multilangmgr.h"
 #include "guiutils.h"
 
-class RecentBrowser : public Gtk::VBox, public DirSelectionListener {
+class RecentBrowser : public Gtk::VBox
+{
+public:
+    typedef sigc::slot<void, const Glib::ustring&> DirSelectionSlot;
 
-        Gtk::ComboBoxText*              recentDirs;
-        sigc::connection             conn;
-        DirBrowserRemoteInterface*   listener;
+private:
+    Gtk::ComboBoxText*              recentDirs;
+    sigc::connection             conn;
+    DirSelectionSlot             selectDir;
 
-    public:
-    
-        RecentBrowser ();
-        
-        void setDirBrowserRemoteInterface (DirBrowserRemoteInterface* l) { listener = l; }
-        
-        void selectionChanged ();
-        void dirSelected (const Glib::ustring& dirname, const Glib::ustring& openfile="");
+public:
+
+    RecentBrowser ();
+
+    void setDirSelector (const DirSelectionSlot& selectDir);
+
+    void selectionChanged ();
+    void dirSelected (const Glib::ustring& dirname, const Glib::ustring& openfile);
 };
 
+inline void RecentBrowser::setDirSelector (const RecentBrowser::DirSelectionSlot& selectDir)
+{
+    this->selectDir = selectDir;
+}
+
 #endif
 
 
