@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -24,9 +24,10 @@
 #include "thresholdadjuster.h"
 #include "toolpanel.h"
 
-class Sharpening : public ToolParamBlock, public ThresholdAdjusterListener, public AdjusterListener, public FoldableToolPanel {
+class Sharpening : public ToolParamBlock, public ThresholdAdjusterListener, public AdjusterListener, public FoldableToolPanel
+{
 
-  protected:
+protected:
     MyComboBoxText* method;
     Adjuster* dradius;
     Adjuster* damount;
@@ -34,7 +35,7 @@ class Sharpening : public ToolParamBlock, public ThresholdAdjusterListener, publ
     Adjuster* diter;
     Gtk::VBox* usm;
     Gtk::VBox* rld;
-    
+
     Adjuster* radius;
     Adjuster* amount;
     Adjuster* eradius;
@@ -45,36 +46,31 @@ class Sharpening : public ToolParamBlock, public ThresholdAdjusterListener, publ
     Gtk::VBox* edgebox;
     Gtk::VBox* hcbox;
     ThresholdAdjuster* threshold;
-    Gtk::CheckButton* enabled;  
-    bool lastEnabled;
-    sigc::connection enaConn;
-    Gtk::CheckButton* edgesonly;  
+    Gtk::CheckButton* edgesonly;
     bool lastEdgesOnly;
     sigc::connection eonlyConn;
-    Gtk::CheckButton* halocontrol;  
+    Gtk::CheckButton* halocontrol;
     bool lastHaloControl;
     sigc::connection hcConn;
 
-
-	
-  public:
+public:
 
     Sharpening ();
     virtual ~Sharpening ();
 
-    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited=NULL); 
-    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited=NULL);
-    void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited=NULL);
+    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited = nullptr);
+    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited = nullptr);
+    void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited = nullptr);
     void setBatchMode   (bool batchMode);
 
     void adjusterChanged (Adjuster* a, double newval);
     void adjusterChanged (ThresholdAdjuster* a, int newBottomLeft, int newTopLeft, int newBottomRight, int newTopRight);
-    void enabled_toggled ();
+    void enabledChanged  ();
     void edgesonly_toggled ();
     void halocontrol_toggled ();
     void method_changed ();
 
-    void setAdjusterBehavior (bool amountadd);
+    void setAdjusterBehavior (bool radiusadd, bool amountadd, bool dampingadd, bool iteradd, bool edgetoladd, bool haloctrladd);
     void trimValues          (rtengine::procparams::ProcParams* pp);
 };
 
