@@ -21,9 +21,13 @@
 #ifndef _SOUNDMAN_
 #define _SOUNDMAN_
 
-#include "../rtengine/safegtk.h"
+namespace Glib
+{
+class ustring;
+}
 
-class SoundManager {
+class SoundManager
+{
 public:
     static void init();
     static void playSoundAsync(const Glib::ustring &sound);
