@@ -29,6 +29,8 @@
 
 class ToneCurve : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel, public rtengine::AutoExpListener, public CurveListener
 {
+private:
+    IdleRegister idle_register;
 
 protected:
     // from HLRecovery
@@ -73,7 +75,6 @@ protected:
     bool nextHLRecons;
 
 public:
-
     ToneCurve ();
     ~ToneCurve ();
 
